summaryrefslogtreecommitdiffstats
path: root/src/widgets/qtextedit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/widgets/qtextedit.cpp')
-rw-r--r--src/widgets/qtextedit.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/widgets/qtextedit.cpp b/src/widgets/qtextedit.cpp
index 09466f459..e2a78743d 100644
--- a/src/widgets/qtextedit.cpp
+++ b/src/widgets/qtextedit.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -1089,7 +1089,7 @@ void TQTextEdit::drawContents( TQPainter *p, int cx, int cy, int cw, int ch )
}
}
// This invocation is retquired to follow dragging of active window
// by the showed candidate window.
updateMicroFocusHint();
}
@@ -5901,7 +5901,7 @@ void TQTextEdit::setReadOnly( bool b )
/*!
Scrolls to the bottom of the document and does formatting if
- retquired.
+ required.
*/
void TQTextEdit::scrollToBottom()
@@ -1089,7 +1089,7 @@ void TQTextEdit::drawContents( TQPainter *p, int cx, int cy, int cw, int ch )
}
}
- // This invocation is retquired to follow dragging of active window
+ // This invocation is required to follow dragging of active window
// by the showed candidate window.
updateMicroFocusHint();